@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -42,7 +42,7 @@ class QSqlQuery;
  */
 class Database : public QObject
 {
-    Q_OBJECT
+	Q_OBJECT
 
 public:
 	Database(QObject *parent = nullptr);
@@ -82,9 +82,16 @@ private:
 	void loadDatabaseInfo();
 
 	/**
-	 * Creates the database information table which contains the database version.
+	 * Saves the database information.
+	 */
+	void saveDatabaseInfo();
+
+	/*
+	 * These methods create new tables, they are used when creating a new database.
 	 */
 	void createDbInfoTable();
+	void createRosterTable();
+	void createMessagesTable();
 
 	/**
 	 * Creates a new database without content.
