@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,16 +31,20 @@
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
-// Application information
-#define APPLICATION_DESCRIPTION "A simple, user-friendly Jabber/XMPP client"
+#include <QLatin1String>
 
 // Kaidan settings
 #define KAIDAN_SETTINGS_AUTH_JID "auth/jid"
-#define KAIDAN_SETTINGS_AUTH_RESOURCE "auth/resource"
+#define KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX "auth/jidResourcePrefix"
 #define KAIDAN_SETTINGS_AUTH_PASSWD "auth/password"
 
-#define KAIDAN_RESOURCE_RANDOM_CHARS \
-	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
+#define KAIDAN_JID_RESOURCE_DEFAULT_PREFIX APPLICATION_DISPLAY_NAME
+
+#define INVITATION_URL "https://i.kaidan.im/#"
+#define APPLICATION_SOURCE_CODE_URL "https://invent.kde.org/kde/kaidan"
+#define ISSUE_TRACKING_URL "https://invent.kde.org/kde/kaidan/issues"
+
+#define MESSAGE_MAX_CHARS 1e4
 
 // XML namespaces
 #define NS_SPOILERS "urn:xmpp:spoiler:0"
@@ -55,4 +59,48 @@
 #define DB_TABLE_ROSTER "Roster"
 #define DB_TABLE_MESSAGES "Messages"
 
+//
+// Credential generation
+//
+
+// Length of generated usernames
+#define GENERATED_USERNAME_LENGTH 6
+
+// Lower bound of the length for generated passwords (inclusive)
+#define GENERATED_PASSWORD_LENGTH_LOWER_BOUND 20
+
+// Upper bound of the length for generated passwords (inclusive)
+#define GENERATED_PASSWORD_LENGTH_UPPER_BOUND 30
+
+// Characters used for password generation
+#define GENERATED_PASSWORD_ALPHABET QLatin1String( \
+	"abcdefghijklmnopqrstuvwxyz" \
+	"ABCDEFGHIJKLMNOPQRSTUVWXYZ" \
+	"`1234567890-=" \
+	"~!@#$%^&*()_+" \
+	"[];'\\,./{}:\"|<>?" \
+)
+
+// Number of characters used for password generation
+#define GENERATED_PASSWORD_ALPHABET_LENGTH GENERATED_PASSWORD_ALPHABET.size()
+
+// QXmpp version compatibility
+#define QXMPP_REQUIRED_VERSION_FOR_REGISTRATION QT_VERSION_CHECK(1, 2, 0)
+
+/**
+ * Path of the JSON server list file
+ */
+#define SERVER_LIST_FILE_PATH QStringLiteral(":/data/servers.json")
+
+/**
+ * Number of servers required in a country so that only servers from that country are
+ * randomly selected.
+ */
+#define SERVER_LIST_MIN_SERVERS_FROM_COUNTRY 2
+
+/**
+ * Name of the @c QQuickImageProvider for Bits of Binary.
+ */
+#define BITS_OF_BINARY_IMAGE_PROVIDER_NAME "bits-of-binary"
+
 #endif // GLOBALS_H
