@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -36,10 +36,12 @@
 #include <QSettings>
 #include <QThread>
 // QXmpp
+#include <QXmppStanza.h>
 #include "qxmpp-exts/QXmppColorGenerator.h"
-#include <QXmppClient.h>
+#include "qxmpp-exts/QXmppUri.h"
 // Kaidan
 #include "AvatarFileStorage.h"
+#include "CredentialsValidator.h"
 #include "Database.h"
 #include "MessageDb.h"
 #include "MessageModel.h"
@@ -48,19 +50,18 @@
 #include "RosterDb.h"
 #include "RosterModel.h"
 
-Kaidan *Kaidan::s_instance = nullptr;
+Kaidan *Kaidan::s_instance;
 
 Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
         : QObject(parent),
-          m_utils(new QmlUtils(this)),
           m_database(new Database()),
           m_dbThrd(new QThread()),
           m_msgDb(new MessageDb()),
           m_rosterDb(new RosterDb(m_database)),
           m_cltThrd(new QThread())
 {
-	Q_ASSERT(!Kaidan::s_instance);
-	Kaidan::s_instance = this;
+	Q_ASSERT(!s_instance);
+	s_instance = this;
 
 	// Database setup
 	m_database->moveToThread(m_dbThrd);
@@ -83,14 +84,14 @@ Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
 	// Load settings
 	//
 
-	creds.jid = m_caches->settings->value(KAIDAN_SETTINGS_AUTH_JID).toString();
-	creds.jidResource = m_caches->settings->value(KAIDAN_SETTINGS_AUTH_RESOURCE)
-	                    .toString();
-	creds.password = QString(QByteArray::fromBase64(m_caches->settings->value(
-	                 KAIDAN_SETTINGS_AUTH_PASSWD).toString().toUtf8()));
-	// use Kaidan as resource, if no set
-	if (creds.jidResource.isEmpty())
-		setJidResource(APPLICATION_DISPLAY_NAME);
+	setJid(m_caches->settings->value(KAIDAN_SETTINGS_AUTH_JID).toString());
+	setJidResourcePrefix(m_caches->settings->value(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX).toString());
+	setPassword(QByteArray::fromBase64(
+		m_caches->settings->value(KAIDAN_SETTINGS_AUTH_PASSWD).toString().toUtf8()
+	));
+	// Use a default prefix for the JID's resource part if no prefix is already set.
+	if (creds.jidResourcePrefix.isEmpty())
+		setJidResourcePrefix(KAIDAN_JID_RESOURCE_DEFAULT_PREFIX);
 	creds.isFirstTry = false;
 
 	//
@@ -101,7 +102,7 @@ Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
 	m_client->setCredentials(creds);
 	m_client->moveToThread(m_cltThrd);
 
-	connect(m_client, &ClientWorker::disconnReasonChanged, this, &Kaidan::setDisconnReason);
+	connect(m_client, &ClientWorker::connectionErrorChanged, this, &Kaidan::setConnectionError);
 	connect(m_cltThrd, &QThread::started, m_client, &ClientWorker::main);
 
 	m_client->setObjectName("XmppClient");
@@ -112,7 +113,7 @@ Kaidan::~Kaidan()
 {
 	delete m_caches;
 	delete m_database;
-	Kaidan::s_instance = nullptr;
+	s_instance = nullptr;
 }
 
 void Kaidan::start()
@@ -125,51 +126,69 @@ void Kaidan::start()
 
 void Kaidan::mainConnect()
 {
-	if (connectionState != ConnectionState::StateDisconnected) {
-		qWarning() << "[main] Tried to connect, even if still connected!"
-		           << "Requesting disconnect.";
-		emit m_client->disconnectRequested();
-	}
-
 	emit m_client->credentialsUpdated(creds);
 	emit m_client->connectRequested();
 }
 
-void Kaidan::mainDisconnect(bool openLogInPage)
+void Kaidan::requestRegistrationForm()
+{
+	emit m_client->credentialsUpdated(creds);
+	emit m_client->registrationFormRequested();
+}
+
+void Kaidan::mainDisconnect()
 {
 	// disconnect the client if connected or connecting
 	if (connectionState != ConnectionState::StateDisconnected)
 		emit m_client->disconnectRequested();
-
-	if (openLogInPage) {
-		// clear password
-		m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_PASSWD);
-		setPassword(QString());
-		// trigger log in page
-		emit newCredentialsNeeded();
-	}
 }
 
 void Kaidan::setConnectionState(QXmppClient::State state)
 {
-	this->connectionState = static_cast<ConnectionState>(state);
-	emit connectionStateChanged();
+	if (this->connectionState != static_cast<ConnectionState>(state)) {
+		this->connectionState = static_cast<ConnectionState>(state);
+		emit connectionStateChanged();
 
-	// Open the possibly cached URI when connected.
-	// This is needed because the XMPP URIs can't be opened when Kaidan is not connected.
-	if (connectionState == ConnectionState::StateConnected && !openUriCache.isEmpty()) {
-		// delay is needed because sometimes the RosterPage needs to be loaded first
-		QTimer::singleShot(300, [=] () {
-			emit xmppUriReceived(openUriCache);
-			openUriCache = "";
-		});
+		// Open the possibly cached URI when connected.
+		// This is needed because the XMPP URIs can't be opened when Kaidan is not connected.
+		if (connectionState == ConnectionState::StateConnected && !openUriCache.isEmpty()) {
+			// delay is needed because sometimes the RosterPage needs to be loaded first
+			QTimer::singleShot(300, [=] () {
+				emit xmppUriReceived(openUriCache);
+				openUriCache = "";
+			});
+		}
 	}
 }
 
-void Kaidan::setDisconnReason(DisconnectionReason reason)
+void Kaidan::setConnectionError(ClientWorker::ConnectionError error)
 {
-	disconnReason = reason;
-	emit disconnReasonChanged();
+	connectionError = error;
+	emit connectionErrorChanged(error);
+}
+
+void Kaidan::deleteCredentials()
+{
+	// Delete the JID.
+	m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_JID);
+	setJid(QString());
+
+	// Delete the password.
+	m_caches->settings->remove(KAIDAN_SETTINGS_AUTH_PASSWD);
+	setPassword(QString());
+
+	emit newCredentialsNeeded();
+}
+
+bool Kaidan::notificationsMuted(const QString &jid)
+{
+	return m_caches->settings->value(QString("muted/") + jid, false).toBool();
+}
+
+void Kaidan::setNotificationsMuted(const QString &jid, bool muted)
+{
+	m_caches->settings->setValue(QString("muted/") + jid, muted);
+	emit notificationsMutedChanged(jid);
 }
 
 void Kaidan::setJid(const QString &jid)
@@ -177,15 +196,17 @@ void Kaidan::setJid(const QString &jid)
 	creds.jid = jid;
 	// credentials were modified -> first try
 	creds.isFirstTry = true;
+	emit jidChanged();
 }
 
-void Kaidan::setJidResource(const QString &jidResource)
+void Kaidan::setJidResourcePrefix(const QString &jidResourcePrefix)
 {
 	// JID resource won't influence the authentication, so we don't need
 	// to set the first try flag and can save it.
-	creds.jidResource = jidResource;
+	creds.jidResourcePrefix = jidResourcePrefix;
 
-	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_RESOURCE, jidResource);
+	m_caches->settings->setValue(KAIDAN_SETTINGS_AUTH_JID_RESOURCE_PREFIX, jidResourcePrefix);
+	emit jidResourcePrefixChanged();
 }
 
 void Kaidan::setPassword(const QString &password)
@@ -193,29 +214,72 @@ void Kaidan::setPassword(const QString &password)
 	creds.password = password;
 	// credentials were modified -> first try
 	creds.isFirstTry = true;
+	emit passwordChanged();
 }
 
-quint8 Kaidan::getDisconnReason() const
+quint8 Kaidan::getConnectionError() const
 {
-	return static_cast<quint8>(disconnReason);
+	return static_cast<quint8>(connectionError);
 }
 
-void Kaidan::addOpenUri(const QByteArray &uri)
+void Kaidan::addOpenUri(const QString &uri)
 {
-	qDebug() << "[main]" << uri;
-
-	if (!uri.startsWith("xmpp:") || !uri.contains("@"))
+	if (!QXmppUri::isXmppUri(uri))
 		return;
 
 	if (connectionState == ConnectionState::StateConnected) {
-		emit xmppUriReceived(QString::fromUtf8(uri));
+		emit xmppUriReceived(uri);
 	} else {
 		//: The link is an XMPP-URI (i.e. 'xmpp:kaidan@muc.kaidan.im?join' for joining a chat)
 		emit passiveNotificationRequested(tr("The link will be opened after you have connected."));
-		openUriCache = QString::fromUtf8(uri);
+		openUriCache = uri;
 	}
 }
 
+bool Kaidan::logInByUri(const QString &uri)
+{
+	if (!QXmppUri::isXmppUri(uri)) {
+		notifyForInvalidLoginUri();
+		return false;
+	}
+
+	QXmppUri parsedUri(uri);
+
+	if (!CredentialsValidator::isAccountJidValid(parsedUri.jid()) || !parsedUri.hasAction(QXmppUri::Action::Login) || !CredentialsValidator::isPasswordValid(parsedUri.password())) {
+		notifyForInvalidLoginUri();
+		return false;
+	}
+
+	setJid(parsedUri.jid());
+	setPassword(parsedUri.password());
+
+	// Connect with the extracted credentials.
+	mainConnect();
+
+	return true;
+}
+
+void Kaidan::notifyForInvalidLoginUri()
+{
+	qWarning() << "[main]" << "No valid login URI found.";
+	emit passiveNotificationRequested(tr("No valid login QR code found."));
+}
+
+ClientWorker *Kaidan::getClient() const
+{
+	return m_client;
+}
+
+RosterDb *Kaidan::rosterDb() const
+{
+	return m_rosterDb;
+}
+
+MessageDb *Kaidan::messageDb() const
+{
+	return m_msgDb;
+}
+
 Kaidan *Kaidan::instance()
 {
 	return s_instance;
