@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -29,45 +29,81 @@
  */
 
 #include "Message.h"
+
+#include <QDomElement>
 #include <QMimeType>
 
-MessageType Message::mediaTypeFromMimeType(const QMimeType &type)
-{
-	if (type.inherits("image/jpeg") || type.inherits("image/png") ||
-	    type.inherits("image/gif"))
-		return MessageType::MessageImage;
-	if (type.inherits("audio/flac") || type.inherits("audio/mp4") ||
-	         type.inherits("audio/ogg") || type.inherits("audio/wav") ||
-	         type.inherits("audio/mpeg") || type.inherits("audio/webm"))
-		return MessageType::MessageAudio;
-	if (type.inherits("video/mpeg") || type.inherits("video/x-msvideo") ||
-	         type.inherits("video/quicktime") || type.inherits("video/mp4") ||
-	         type.inherits("video/x-matroska"))
-		return MessageType::MessageVideo;
-	if (type.inherits("text/plain"))
-		return MessageType::MessageDocument;
-	return MessageType::MessageFile;
+static bool operator==(const QXmppStanza::Error &left, const QXmppStanza::Error &right) {
+	return left.code() == right.code()
+	       && left.text() == right.text()
+	       && left.condition() == right.condition()
+	       && left.type() == right.type();
+}
+
+static bool operator==(const QXmppElement &left, const QXmppElement &right) {
+	return left.sourceDomElement() == right.sourceDomElement()
+	       && left.attributeNames() == right.attributeNames()
+	       && left.tagName() == right.tagName()
+	       && left.value() == right.value();
+}
+
+static bool operator==(const QXmppExtendedAddress &left, const QXmppExtendedAddress &right) {
+	return left.description() == right.description()
+	       && left.jid() == right.jid()
+	       && left.type() == right.type()
+	       && left.isDelivered() == right.isDelivered();
+}
+
+static bool operator==(const QXmppStanza &left, const QXmppStanza &right) {
+	return left.to() == right.to()
+	       && left.from() == right.from()
+	       && left.id() == right.id()
+	       && left.lang() == right.lang()
+	       && left.error() == right.error()
+	       && left.extensions() == right.extensions()
+	       && left.extendedAddresses() == right.extendedAddresses()
+	       && left.isXmppStanza() == right.isXmppStanza();
+}
+
+static bool operator==(const QXmppMessage &left, const QXmppMessage &right) {
+	return operator==(static_cast<const QXmppStanza &>(left), static_cast<const QXmppStanza &>(right))
+	       && left.body() == right.body()
+	       && left.isAttentionRequested() == right.isAttentionRequested()
+	       && left.isReceiptRequested() == right.isReceiptRequested()
+	       && left.mucInvitationJid() == right.mucInvitationJid()
+	       && left.mucInvitationPassword() == right.mucInvitationPassword()
+	       && left.mucInvitationReason() == right.mucInvitationReason()
+	       && left.receiptId() == right.receiptId()
+	       && left.stamp() == right.stamp()
+	       && left.state() == right.state()
+	       && left.subject() == right.subject()
+	       && left.thread() == right.thread()
+	       && left.type() == right.type()
+	       && left.xhtml() == right.xhtml()
+	       && left.isMarkable() == right.isMarkable()
+	       && left.markedId() == right.markedId()
+	       && left.markedThread() == right.markedThread()
+	       && left.marker() == right.marker()
+	       && left.isPrivate() == right.isPrivate()
+	       && left.isXmppStanza() == right.isXmppStanza()
+	       && left.outOfBandUrl() == right.outOfBandUrl()
+	       && left.replaceId() == right.replaceId();
 }
 
 bool Message::operator==(const Message &m) const
 {
-	return m.id() == id() &&
-	       m.body() == body() &&
-	       m.from() == from() &&
-	       m.to() == to() &&
-	       m.type() == type() &&
-	       m.stamp() == stamp() &&
-#if (QXMPP_VERSION) >= QT_VERSION_CHECK(1, 0, 0)
-	       m.outOfBandUrl() == outOfBandUrl() &&
-#endif
-	       m.isSent() == isSent() &&
-	       m.isDelivered() == isDelivered() &&
-	       m.mediaType() == mediaType() &&
-	       m.mediaContentType() == mediaContentType() &&
-	       m.mediaLocation() == mediaLocation() &&
-	       m.isEdited() == isEdited() &&
-	       m.spoilerHint() == spoilerHint() &&
-	       m.isSpoiler() == isSpoiler();
+	return ::operator==(static_cast<const QXmppMessage &>(m), static_cast<const QXmppMessage &>(*this))
+	       && m.mediaType() == mediaType()
+	       && m.sentByMe() == sentByMe()
+	       && m.isEdited() == isEdited()
+	       && m.isSent() == isSent()
+	       && m.isDelivered() == isDelivered()
+	       && m.mediaLocation() == mediaLocation()
+	       && m.mediaContentType() == mediaContentType()
+	       && m.mediaLastModified() == mediaLastModified()
+	       && m.mediaSize() == mediaSize()
+	       && m.isSpoiler() == isSpoiler()
+	       && m.spoilerHint() == spoilerHint();
 }
 
 bool Message::operator!=(const Message &m) const
@@ -184,15 +220,3 @@ void Message::setSpoilerHint(const QString &spoilerHint)
 {
 	m_spoilerHint = spoilerHint;
 }
-
-#if (QXMPP_VERSION) < QT_VERSION_CHECK(1, 0, 0)
-QString Message::outOfBandUrl() const
-{
-	return m_outOfBandUrl;
-}
-
-void Message::setOutOfBandUrl(const QString &outOfBandUrl)
-{
-	m_outOfBandUrl = outOfBandUrl;
-}
-#endif
