@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -45,8 +45,6 @@ using namespace Enums;
 class Message : public QXmppMessage
 {
 public:
-	static MessageType mediaTypeFromMimeType(const QMimeType&);
-
 	/**
 	 * Compares another @c Message with this. Only attributes that are saved in the
 	 * database are checked.
@@ -87,11 +85,6 @@ public:
 	QString spoilerHint() const;
 	void setSpoilerHint(const QString &spoilerHint);
 
-#if (QXMPP_VERSION) < QT_VERSION_CHECK(1, 0, 0)
-	QString outOfBandUrl() const;
-	void setOutOfBandUrl(const QString &outOfBandUrl);
-#endif
-
 private:
 	/**
 	 * Media type of the message, e.g. a text or image.
@@ -131,7 +124,7 @@ private:
 	/**
 	 * Size of the file in bytes.
 	 */
-	qint64 m_mediaSize;
+	qint64 m_mediaSize = 0;
 
 	/**
 	 * Timestamp of the last modification date of the file locally on disk.
@@ -147,10 +140,6 @@ private:
 	 * Hint of the spoiler message.
 	 */
 	QString m_spoilerHint;
-
-#if (QXMPP_VERSION) < QT_VERSION_CHECK(1, 0, 0)
-	QString m_outOfBandUrl;
-#endif
 };
 
 #endif // MESSAGE_H
