@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -39,12 +39,9 @@
 
 class Kaidan;
 class MessageModel;
-class QMimeType;
 class QXmppMessage;
 class QXmppDiscoveryIq;
-#if (QXMPP_VERSION) >= QT_VERSION_CHECK(1, 0, 0)
 class QXmppCarbonManager;
-#endif
 
 /**
  * @class MessageHandler Handler for incoming and outgoing messages.
@@ -85,9 +82,7 @@ private:
 	QXmppClient *client;
 	QXmppMessageReceiptManager receiptManager;
 	MessageModel *model;
-#if (QXMPP_VERSION) >= QT_VERSION_CHECK(1, 0, 0)
 	QXmppCarbonManager *carbonManager;
-#endif
 	QString chatPartner;
 };
 
