@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ class MessageModel;
 class RosterModel : public QAbstractListModel
 {
 	Q_OBJECT
+
 public:
 	enum RosterItemRoles {
 		JidRole,
@@ -66,6 +67,8 @@ signals:
 	void updateItemRequested(const QString &jid,
 	                         const std::function<void (RosterItem &)> &updateItem);
 	void replaceItemsRequested(const QHash<QString, RosterItem> &items);
+	void setLastMessageRequested(const QString &contactJid, const QString &newLastMessage);
+	void setLastExchangedRequested(const QString &contactJid, const QDateTime &newLastExchanged);
 
 private slots:
 	void handleItemsFetched(const QVector<RosterItem> &items);
@@ -75,9 +78,13 @@ private slots:
 	void updateItem(const QString &jid,
 	                const std::function<void (RosterItem &)> &updateItem);
 	void replaceItems(const QHash<QString, RosterItem> &items);
+	void setLastMessage(const QString &contactJid, const QString &newLastMessage);
+	void setLastExchanged(const QString &contactJid, const QDateTime &newLastExchanged);
 
 private:
 	void insertContact(int i, const RosterItem &item);
+	int updateItemPosition(int currentIndex);
+	int positionToInsert(const RosterItem &item);
 
 	RosterDb *rosterDb;
 	QVector<RosterItem> m_items;
