@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2019 Kaidan developers and contributors
+ *  Copyright (C) 2016-2020 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -29,34 +29,54 @@
  */
 
 // Qt
+#include <QAbstractSocket>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QDebug>
+#include <QDir>
 #include <QIcon>
 #include <QLibraryInfo>
 #include <QLocale>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QTranslator>
+#include <QStandardPaths>
 #include <qqml.h>
 
 // QXmpp
 #include "qxmpp-exts/QXmppUploadManager.h"
 #include <QXmppClient.h>
+#include <QXmppRegisterIq.h>
 
 // Kaidan
 #include "AvatarFileStorage.h"
+#include "BitsOfBinaryImageProvider.h"
+#include "CredentialsGenerator.h"
+#include "CredentialsValidator.h"
+#include "DataFormModel.h"
 #include "EmojiModel.h"
 #include "Enums.h"
-#include "Globals.h"
 #include "Kaidan.h"
 #include "Message.h"
 #include "MessageModel.h"
 #include "PresenceCache.h"
 #include "QmlUtils.h"
+#include "RegistrationDataFormFilterModel.h"
+#include "RegistrationManager.h"
 #include "RosterModel.h"
+#include "RosterFilterProxyModel.h"
 #include "StatusBar.h"
+#include "ServerListModel.h"
 #include "UploadManager.h"
+#include "Utils.h"
+#include "QrCodeGenerator.h"
+#include "QrCodeScannerFilter.h"
+#include "VCardModel.h"
+#include "CameraModel.h"
+#include "AudioDeviceModel.h"
+#include "MediaSettingModel.h"
+#include "MediaUtils.h"
+#include "MediaRecorder.h"
 
 #ifdef STATIC_BUILD
 #include "static_plugins.h"
@@ -130,8 +150,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 		freopen("CONOUT$", "w", stderr);
 	}
 #endif
-	// initialize random generator
-	qsrand(time(nullptr));
 
 	//
 	// App
@@ -161,6 +179,36 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	SingleApplication app(argc, argv, true);
 #endif
 
+#ifdef APPIMAGE
+	QFileInfo executable(QCoreApplication::applicationFilePath());
+
+	if (executable.isSymLink()) {
+		executable.setFile(executable.symLinkTarget());
+	}
+
+	QString gstreamerPluginsPath;
+
+	// Try to use deployed plugins if any...
+#if defined(TARGET_GSTREAMER_PLUGINS)
+	gstreamerPluginsPath = QString::fromLocal8Bit(TARGET_GSTREAMER_PLUGINS);
+
+	if (!gstreamerPluginsPath.isEmpty()) {
+		gstreamerPluginsPath = QDir::cleanPath(QString::fromLatin1("%1/../..%2")
+							.arg(executable.absolutePath(), gstreamerPluginsPath));
+	}
+	qDebug() << "Looking for gstreamer in " << gstreamerPluginsPath;
+#else
+	qFatal("Please provide the unified directory containing the gstreamer plugins and gst-plugin-scanner.");
+#endif
+
+#if defined(QT_DEBUG)
+	qputenv("GST_DEBUG", "ERROR:5,WARNING:5,INFO:5,DEBUG:5,LOG:5");
+#endif
+	qputenv("GST_PLUGIN_PATH_1_0", QByteArray());
+	qputenv("GST_PLUGIN_SYSTEM_PATH_1_0", gstreamerPluginsPath.toLocal8Bit());
+	qputenv("GST_PLUGIN_SCANNER_1_0", QString::fromLatin1("%1/gst-plugin-scanner").arg(gstreamerPluginsPath).toLocal8Bit());
+#endif // APPIMAGE
+
 	// register qMetaTypes
 	qRegisterMetaType<RosterItem>("RosterItem");
 	qRegisterMetaType<RosterModel*>("RosterModel*");
@@ -173,7 +221,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<Qt::ApplicationState>("Qt::ApplicationState");
 	qRegisterMetaType<QXmppClient::State>("QXmppClient::State");
 	qRegisterMetaType<MessageType>("MessageType");
-	qRegisterMetaType<DisconnectionReason>("DisconnectionReason");
 	qRegisterMetaType<TransferJob*>("TransferJob*");
 	qRegisterMetaType<QmlUtils*>("QmlUtils*");
 	qRegisterMetaType<QVector<Message>>("QVector<Message>");
@@ -182,11 +229,31 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<std::function<void(RosterItem&)>>("std::function<void(RosterItem&)>");
 	qRegisterMetaType<std::function<void(Message&)>>("std::function<void(Message&)>");
 	qRegisterMetaType<ClientWorker::Credentials>("ClientWorker::Credentials");
+	qRegisterMetaType<QXmppVCardIq>("QXmppVCardIq");
+	qRegisterMetaType<QMimeType>();
+	qRegisterMetaType<CameraInfo>();
+	qRegisterMetaType<AudioDeviceInfo>();
+	qRegisterMetaType<MediaSettings>();
+	qRegisterMetaType<ImageEncoderSettings>();
+	qRegisterMetaType<AudioEncoderSettings>();
+	qRegisterMetaType<VideoEncoderSettings>();
+	qRegisterMetaType<CredentialsValidator*>();
+	qRegisterMetaType<QXmppStanza::Error>("QXmppStanza::Error");
+
 	// Enums for c++ member calls using enums
 	qRegisterMetaType<Enums::ConnectionState>();
-	qRegisterMetaType<Enums::DisconnectionReason>();
+	qRegisterMetaType<ClientWorker::ConnectionError>();
 	qRegisterMetaType<Enums::MessageType>();
 	qRegisterMetaType<Enums::AvailabilityTypes>();
+	qRegisterMetaType<CommonEncoderSettings::EncodingQuality>();
+	qRegisterMetaType<CommonEncoderSettings::EncodingMode>();
+	qRegisterMetaType<AudioDeviceModel::Mode>();
+	qRegisterMetaType<MediaRecorder::Type>();
+	qRegisterMetaType<MediaRecorder::AvailabilityStatus>();
+	qRegisterMetaType<MediaRecorder::State>();
+	qRegisterMetaType<MediaRecorder::Status>();
+	qRegisterMetaType<MediaRecorder::Error>();
+	qRegisterMetaType<ServerListModel::Role>();
 
 	// Qt-Translator
 	QTranslator qtTranslator;
@@ -236,22 +303,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	}
 #endif
 
-
 	//
 	// Kaidan back-end
 	//
-
-	Kaidan kaidan(&app, !parser.isSet("disable-xml-log"));
+	auto *kaidan = new Kaidan(&app, !parser.isSet("disable-xml-log"));
 
 #if !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID)
 	// receive messages from other instances of Kaidan
 	Kaidan::connect(&app, &SingleApplication::receivedMessage,
-			&kaidan, &Kaidan::receiveMessage);
+	                kaidan, &Kaidan::receiveMessage);
 #endif
 
 	// open the XMPP-URI/link (if given)
 	if (!parser.positionalArguments().isEmpty())
-		kaidan.addOpenUri(parser.positionalArguments().first().toUtf8());
+		kaidan->addOpenUri(parser.positionalArguments().first());
 
 	//
 	// QML-GUI
@@ -262,6 +327,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	}
 
 	QQmlApplicationEngine engine;
+
+	engine.addImageProvider(QLatin1String(BITS_OF_BINARY_IMAGE_PROVIDER_NAME), BitsOfBinaryImageProvider::instance());
+
 	// QtQuickControls2 Style
 	if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
 #ifdef Q_OS_WIN
@@ -279,16 +347,56 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterType<StatusBar>("StatusBar", 0, 1, "StatusBar");
 	qmlRegisterType<EmojiModel>("EmojiModel", 0, 1, "EmojiModel");
 	qmlRegisterType<EmojiProxyModel>("EmojiModel", 0, 1, "EmojiProxyModel");
+	qmlRegisterType<QrCodeScannerFilter>(APPLICATION_ID, 1, 0, "QrCodeScannerFilter");
+	qmlRegisterType<VCardModel>(APPLICATION_ID, 1, 0, "VCardModel");
+	qmlRegisterType<RosterFilterProxyModel>(APPLICATION_ID, 1, 0, "RosterFilterProxyModel");
+	qmlRegisterType<CameraModel>(APPLICATION_ID, 1, 0, "CameraModel");
+	qmlRegisterType<AudioDeviceModel>(APPLICATION_ID, 1, 0, "AudioDeviceModel");
+	qmlRegisterType<MediaSettingsContainerModel>(APPLICATION_ID, 1, 0, "MediaSettingsContainerModel");
+	qmlRegisterType<MediaSettingsResolutionModel>(APPLICATION_ID, 1, 0, "MediaSettingsResolutionModel");
+	qmlRegisterType<MediaSettingsQualityModel>(APPLICATION_ID, 1, 0, "MediaSettingsQualityModel");
+	qmlRegisterType<MediaSettingsImageCodecModel>(APPLICATION_ID, 1, 0, "MediaSettingsImageCodecModel");
+	qmlRegisterType<MediaSettingsAudioCodecModel>(APPLICATION_ID, 1, 0, "MediaSettingsAudioCodecModel");
+	qmlRegisterType<MediaSettingsAudioSampleRateModel>(APPLICATION_ID, 1, 0, "MediaSettingsAudioSampleRateModel");
+	qmlRegisterType<MediaSettingsVideoCodecModel>(APPLICATION_ID, 1, 0, "MediaSettingsVideoCodecModel");
+	qmlRegisterType<MediaSettingsVideoFrameRateModel>(APPLICATION_ID, 1, 0, "MediaSettingsVideoFrameRateModel");
+	qmlRegisterType<MediaRecorder>(APPLICATION_ID, 1, 0, "MediaRecorder");
+	qmlRegisterType<CredentialsGenerator>(APPLICATION_ID, 1, 0, "CredentialsGenerator");
+	qmlRegisterType<CredentialsValidator>(APPLICATION_ID, 1, 0, "CredentialsValidator");
+	qmlRegisterType<QrCodeGenerator>(APPLICATION_ID, 1, 0, "QrCodeGenerator");
+	qmlRegisterType<RegistrationDataFormFilterModel>(APPLICATION_ID, 1, 0, "RegistrationDataFormFilterModel");
+	qmlRegisterType<ServerListModel>(APPLICATION_ID, 1, 0, "ServerListModel");
 
 	qmlRegisterUncreatableType<QAbstractItemModel>("EmojiModel", 0, 1, "QAbstractItemModel", "Used by proxy models");
 	qmlRegisterUncreatableType<Emoji>("EmojiModel", 0, 1, "Emoji", "Used by emoji models");
+	qmlRegisterUncreatableType<TransferJob>(APPLICATION_ID, 1, 0, "TransferJob", "TransferJob type usable");
+	qmlRegisterUncreatableType<QMimeType>(APPLICATION_ID, 1, 0, "QMimeType", "QMimeType type usable");
+	qmlRegisterUncreatableType<CameraInfo>(APPLICATION_ID, 1, 0, "CameraInfo", "CameraInfo type usable");
+	qmlRegisterUncreatableType<AudioDeviceInfo>(APPLICATION_ID, 1, 0, "AudioDeviceInfo", "AudioDeviceInfo type usable");
+	qmlRegisterUncreatableType<MediaSettings>(APPLICATION_ID, 1, 0, "MediaSettings", "MediaSettings type usable");
+	qmlRegisterUncreatableType<CommonEncoderSettings>(APPLICATION_ID, 1, 0, "CommonEncoderSettings", "CommonEncoderSettings type usable");
+	qmlRegisterUncreatableType<ImageEncoderSettings>(APPLICATION_ID, 1, 0, "ImageEncoderSettings", "ImageEncoderSettings type usable");
+	qmlRegisterUncreatableType<AudioEncoderSettings>(APPLICATION_ID, 1, 0, "AudioEncoderSettings", "AudioEncoderSettings type usable");
+	qmlRegisterUncreatableType<VideoEncoderSettings>(APPLICATION_ID, 1, 0, "VideoEncoderSettings", "VideoEncoderSettings type usable");
+	qmlRegisterUncreatableType<ClientWorker>(APPLICATION_ID, 1, 0, "ClientWorker", "Cannot create object; only enums defined!");
+	qmlRegisterUncreatableType<DataFormModel>(APPLICATION_ID, 1, 0, "DataFormModel", "Cannot create object; only enums defined!");
+	qmlRegisterUncreatableType<RegistrationManager>(APPLICATION_ID, 1, 0, "RegistrationManager", "Cannot create object; only enums defined!");
 
-	qmlRegisterUncreatableMetaObject(Enums::staticMetaObject, APPLICATION_ID,
-		1, 0, "Enums", "Can't create object; only enums defined!");
+	qmlRegisterUncreatableMetaObject(Enums::staticMetaObject, APPLICATION_ID, 1, 0, "Enums", "Can't create object; only enums defined!");
+
+	qmlRegisterSingletonType<MediaUtils>("MediaUtils", 0, 1, "MediaUtilsInstance", [](QQmlEngine *, QJSEngine *) {
+		QObject *instance = new MediaUtils(qApp);
+		return instance;
+	});
+	qmlRegisterSingletonType<QmlUtils>(APPLICATION_ID, 1, 0, "Utils", [](QQmlEngine *, QJSEngine *) {
+		return static_cast<QObject*>(QmlUtils::instance());
+	});
+	qmlRegisterSingletonType<Kaidan>(APPLICATION_ID, 1, 0, "Kaidan", [](QQmlEngine *, QJSEngine *) {
+		return static_cast<QObject*>(Kaidan::instance());
+	});
 
-	engine.rootContext()->setContextProperty("kaidan", &kaidan);
 	engine.load(QUrl("qrc:/qml/main.qml"));
-	if(engine.rootObjects().isEmpty())
+	if (engine.rootObjects().isEmpty())
 		return -1;
 
 #ifdef Q_OS_ANDROID
